at_onboarding_cli
library
Classes
-
AtOnboardingPreference
-
-
AtOnboardingService
-
-
AtOnboardingServiceImpl
-
Service implementation responsible for onboarding and authenticating atSigns.
-
AuthCliArgs
-
-
AuthKeyType
-
-
EnrollmentDetails
-
-
GetFreeAtsign
-
This is a
RegisterApiTask that fetches a free atsign
throws AtException with concerned message which was encountered in the
HTTP GET/POST request
-
OnboardingUtil
-
class containing utilities to perform registration of a free atsign
-
Register
-
Class containing logic to register a free atsign to email provided
through
args by utilizing methods defined in RegisterUtil
Requires List<String> args containing the following arguments: email
-
RegisterAtsign
-
This is a
RegisterApiTask that registers a free atsign fetched in
GetFreeAtsign to the email provided as args
throws AtException with concerned message which was encountered in the
HTTP GET/POST request
-
RegistrationFlow
-
class that handles multiple tasks of type
RegisterApiTask
Initialized with a params map that needs to be populated with - email and api host address
add method can be used to add tasksRegisterApiTask to the processFlow
start needs to be called after all required tasks are added to the processFlow
-
ValidateOtp
-
This is a
RegisterApiTask that validates the otp which was sent as a part
of RegisterAtsign to email provided in args
throws AtException with concerned message which was encountered in the
HTTP GET/POST request