AtOnboardingPreference class
Properties
-
apkamAuthRetryDurationMins
↔ int
-
getter/setter pair
-
appName
↔ String?
-
getter/setter pair
-
atClientParticulars
↔ AtClientParticulars
-
getter/setter pairinherited
-
atKeysFilePath
↔ String?
-
specify path of .atKeysFile containing encryption keys
getter/setter pair
-
atProtocolEmitted
↔ Version
-
Poorly named variable which used to control some aspects of at_client's
default data encryption. Is now fully ignored.
getter/setter pairinherited
-
authMode
↔ PkamAuthMode
-
getter/setter pair
-
commitLogPath
↔ String?
-
Local device path of commit log
getter/setter pairinherited
-
cramSecret
↔ String?
-
Shared secret of the atSign
getter/setter pairinherited
-
decryptPackets
↔ bool
-
OptionalParameter when set to true logs TLS Keys to file.
getter/setter pairinherited
-
deviceName
↔ String?
-
getter/setter pair
-
downloadPath
↔ String?
-
Default path to download stream files
getter/setter pairinherited
-
enforceNamespace
↔ bool
-
AtClient.put uses this parameter to decide whether to check for presence of a namespace in the
string representation of the AtKey.
getter/setter pairinherited
-
expiryCheckTimeInterval
↔ Duration
-
Time interval for the scheduled task that removes expired keys from local keyStore
getter/setter pairinherited
-
fetchOfflineNotifications
↔ bool
-
Fetch the notifications received when the client is offline. Defaults to true.
Set to false to ignore the notifications received when device is offline.
getter/setter pairinherited
-
fileEncryptionChunkSize
↔ int
-
Default chunk size for file encryption and decryption
getter/setter pairinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hashingAlgoType
↔ HashingAlgoType
-
hashing algorithm to use for pkam authentication
getter/setter pairinherited
-
hiveStoragePath
↔ String?
-
Local device path of hive storage
getter/setter pairinherited
-
isLocalStoreRequired
↔ bool
-
getter/setter pairinherited
-
isUsingProxy
→ bool
-
Flag to indicate if we're using a proxy server for connection
no setter
-
keyStoreSecret
↔ List<int>?
-
Secret key to encrypt keystore data
getter/setter pairinherited
-
maxDataSize
↔ int
-
The maximum size of the value that a secondary server can store.
BufferOverFlowException is thrown when size of the value exceeds the maxDataSize
getter/setter pairinherited
-
monitorAutoStart
↔ bool
-
- when true, then the notifications monitor will be started either the
first time that
NotificationService.subscribe is called by the
application code, or 30 seconds after creation of the
NotificationService if there have been no subscriptions.
- when false, then the notifications monitor
will not be started until explicitly requested to do so by the
application calling
NotificationService.startListening
getter/setter pairinherited
-
monitorHeartbeatInterval
↔ Duration
-
The NotificationService maintains a connection which monitors for new
notifications being delivered from the atServer. Because network weather
is real, and because it is generally essential for client programs to
receive notifications consistently, a heartbeat
no-op command is sent
to the atServer periodically, at this interval
getter/setter pairinherited
-
monitorHeartbeatResponseTimeout
↔ Duration
-
When a heartbeat is sent by the notifications monitor, we wait for this
length of time to receive a response. If no response is received, then
the connection is closed, and the notifications monitor will reconnect.
getter/setter pairinherited
-
namespace
↔ String?
-
Specifies the namespace of an app.
getter/setter pairinherited
-
outboundConnectionTimeout
↔ int
-
Idle time in milliseconds of connection to secondary server. Default to 10 minutes.
getter/setter pairinherited
-
passPhrase
↔ String?
-
The password (or pass-phrase) with which the atKeys file is encrypted/decrypted.
getter/setter pair
-
pathToCerts
↔ String?
-
OptionalParameter path to trusted certificates. Required to create security context.
getter/setter pairinherited
-
privateKey
↔ String?
-
Private key of the atSign
getter/setter pairinherited
-
publicKeyId
↔ String?
-
if authMode is sim, specify publicKeyId to be read from sim
getter/setter pair
-
qrCodePath
↔ String?
-
specify path of qr code containing cram secret
getter/setter pair
-
registrarUrl
↔ String
-
the hostName of the registrar which will be used to activate the atsign
getter/setter pair
-
remoteLocalPref
↔ RemoteLocalPref
-
Set this to
RemoteLocalPref.remoteOnly
if you require all data operations (get / put / delete) to be performed
on the remote atServer rather than on local storage. (When operations are
performed locally, we depend on sync to get eventual consistency between
local and remote.
getter/setter pairinherited
-
rootDomain
↔ String
-
Domain of the root server. Defaults to root.atsign.org
getter/setter pairinherited
-
rootPort
↔ int
-
Port of the root server. Defaults to 64
getter/setter pairinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
signingAlgoType
↔ SigningAlgoType
-
signing algorithm to use for pkam authentication
getter/setter pairinherited
-
skipSync
↔ bool
-
getter/setter pair
-
syncBatchSize
↔ int
-
Number of keys to batch for sync to secondary server
getter/setter pairinherited
-
syncIntervalMins
↔ int
-
Frequency of sync task to run in minutes. Defaults to 10 minutes.
getter/setter pairinherited
-
syncPageLimit
↔ int
-
The number of keys to pull from cloud secondary to local secondary in a single call.
getter/setter pairinherited
-
syncRegex
↔ String?
-
regex to perform sync
getter/setter pairinherited
-
syncStrategy
↔ SyncStrategy?
-
Syncing strategy of the client
SyncStrategy
Deprecated Use SyncService
getter/setter pairinherited
-
tlsKeysSavePath
↔ String?
-
OptionalParameter location where the TLS keys will be saved when decryptPackets is set to true
getter/setter pairinherited
-
useAtChops
↔ bool
-
getter/setter pairinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited